@@ -1,15 +1,25 @@
+"""
+Visualize directory structure
+"""
+
 import os
 import sys
 import argparse
 import pathlib2
+from typing import Dict, List
 from fmtree.core.scraper import Scraper
 from fmtree.core.format import TreeCommandFormatter, HTMLFormatter, MarkdownContentFormatter
 from fmtree.core.filter import ExtensionFilter
 from fmtree.core.sorter import Sorter
 
 
-def validate_args(args_dict):
-    def count_args(keys):
+def validate_args(args_dict: Dict) -> None:
+    """Validate command line arguments
+
+    :param args_dict: dict containing command line arguments
+    :type args_dict: Dict
+    """
+    def count_args(keys: List[str]):
         count = 0
         for key in keys:
             count += 1 if args_dict[key] else 0
@@ -29,7 +39,13 @@ def validate_args(args_dict):
         args_dict['stdout'] = True  # if no output location is set, use stdout
 
 
-def main(args_dict: dict):
+def main(args_dict: Dict):
+    """Main function of fmtree.visualizer.visualize module
+
+    :param args_dict: parsed arguments as a dictionary
+    :type args_dict: Dict
+    :raises ValueError: no proper format set
+    """
     validate_args(args_dict)
     path = pathlib2.Path(args_dict['input']).absolute()
     scraper = Scraper(path, scrape_now=False, keep_empty_dir=False, depth=args_dict['depth'])
@@ -59,7 +75,7 @@ def main(args_dict: dict):
 if __name__ == '__main__':
     parser = argparse.ArgumentParser("fmtree visualizer argument parser")
     parser.add_argument('--debug', action='store_true', help='debug mode')
-    parser.add_argument('input', help='input path')
+    parser.add_argument('input', default='.', help='input path')
 
     # output location, there can be multiple output
     parser.add_argument('--stdout', action='store_true', help='output to stdout')
